@@ -2,15 +2,16 @@ import logging
 from copy import deepcopy
 from pymich.middle_end.ir.vm_types import Instr, Contract
 import pymich.middle_end.ir.instr_types as t
-from pymich.middle_end.ir import vm_types
 from typing import List, Optional, Type, Callable
-from pymich.middle_end.ir.typechecker import TypeChecker
 
-from pymich.utils.exceptions import InvalidMichelsonException, MichelsonTypecheckerException, StackLengthException, StackTopTypeException, TypeException
+from pymich.utils.exceptions import (
+    InvalidMichelsonException,
+    StackLengthException,
+    TypeException,
+)
 import pymich.utils.exceptions as E
 
 
-
 def simplify_type(el_type):
     if isinstance(el_type, t.Record):
         return simplify_type(el_type.get_type())
@@ -48,7 +49,7 @@ class StackType:
 
     def pop(self):
         if not len(self._stack_type):
-            raise StackLengthException(f"Cannot pop an empty stack.")
+            raise StackLengthException("Cannot pop an empty stack.")
 
         el = self._stack_type[-1]
         del self._stack_type[-1]
@@ -83,7 +84,9 @@ class StackType:
         return len(self._stack_type)
 
     def __eq__(self, other: "StackType"):
-        is_universal = lambda s: len(s) and s.get_at_depth(0) == t.Universal()
+        def is_universal(s):
+            return len(s) and s.get_at_depth(0) == t.Universal()
+
         if is_universal(self) or is_universal(other):
             return True
         return self._stack_type == other._stack_type
@@ -116,22 +119,25 @@ class StackType:
                 raise E.StackTopTypeException(
                     "",
                     stack_top_type,
-                    self._stack_type[:-len(stack_top_type)],
+                    self._stack_type[: -len(stack_top_type)],
                     error_message,
                 )
 
 
-def default_prepare_stack_for_branch(is_true_branch: bool, temp_stack: StackType) -> StackType:
+def default_prepare_stack_for_branch(
+    is_true_branch: bool, temp_stack: StackType
+) -> StackType:
     temp_stack.pop()
     return temp_stack
 
+
 def generic_if(
-        instruction_name: str,
-        instruction: Instr,
-        operand_type: Type[t.Type],
-        stack: StackType,
-        prepare_stack_for_branch: Optional[Callable[[bool, StackType], StackType]] = None,
-    ):
+    instruction_name: str,
+    instruction: Instr,
+    operand_type: Type[t.Type],
+    stack: StackType,
+    prepare_stack_for_branch: Optional[Callable[[bool, StackType], StackType]] = None,
+):
     stack.assert_min_length(1, f"Cannot call {instruction_name} on an empty stack.")
     if isinstance(stack.get_at_depth(0), operand_type):
         if (
@@ -142,26 +148,38 @@ def generic_if(
             branch_true = instruction.args[0]
             branch_false = instruction.args[1]
 
-            prepare_stack = prepare_stack_for_branch if prepare_stack_for_branch else default_prepare_stack_for_branch
+            prepare_stack = (
+                prepare_stack_for_branch
+                if prepare_stack_for_branch
+                else default_prepare_stack_for_branch
+            )
 
             typechecker = MichelsonTypeChecker()
 
             # True branch
             temp_stack = deepcopy(stack)
             temp_stack = prepare_stack(True, temp_stack)
-            typechecker.typecheck(init_stack_type=deepcopy(temp_stack), instructions=branch_true)
+            typechecker.typecheck(
+                init_stack_type=deepcopy(temp_stack), instructions=branch_true
+            )
             stack_branch_true = typechecker.stack
 
             # False branch
             temp_stack = deepcopy(stack)
             temp_stack = prepare_stack(False, temp_stack)
-            typechecker.typecheck(init_stack_type=deepcopy(temp_stack), instructions=branch_false)
+            typechecker.typecheck(
+                init_stack_type=deepcopy(temp_stack), instructions=branch_false
+            )
             stack_branch_false = typechecker.stack
 
-            if len(stack_branch_true) and isinstance(stack_branch_true.get_at_depth(0), t.Universal):
+            if len(stack_branch_true) and isinstance(
+                stack_branch_true.get_at_depth(0), t.Universal
+            ):
                 stack_branch_true.replace_stack(stack_branch_false)
 
-            if len(stack_branch_false) and isinstance(stack_branch_false.get_at_depth(0), t.Universal):
+            if len(stack_branch_false) and isinstance(
+                stack_branch_false.get_at_depth(0), t.Universal
+            ):
                 stack_branch_false.replace_stack(stack_branch_true)
 
             if stack_branch_true != stack_branch_false:
@@ -199,15 +217,17 @@ class TypeChecker:
         else:
             self.stack = stack
 
-    def assert_valid_michelson(self, cond: bool, message = ""):
+    def assert_valid_michelson(self, cond: bool, message=""):
         if not cond:
             raise InvalidMichelsonException(message)
 
-    def assert_el_has_constructor_type(self, el: Type, constructor_type: Type[t.Type], message = ""):
+    def assert_el_has_constructor_type(
+        self, el: Type, constructor_type: Type[t.Type], message=""
+    ):
         if not isinstance(el, constructor_type):
             raise TypeException(el, constructor_type, 0)
 
-    def assert_type(self, el: Type, should_be: Type, message = ""):
+    def assert_type(self, el: Type, should_be: Type, message=""):
         if el != should_be:
             raise TypeException(el, should_be, 0)
 
@@ -246,7 +266,6 @@ class ComparaisonOperatorTypeChecker(TypeChecker):
             )
 
 
-
 class BooleanTypeChecker(TypeChecker):
     def typecheck_or(self):
         self.stack.assert_min_length(2, "OR requires a minimum stack depth of 2.")
@@ -286,7 +305,6 @@ class BooleanTypeChecker(TypeChecker):
                 [first_operand, second_operand],
             )
 
-
     def typecheck_xor(self):
         self.stack.assert_min_length(2, "XOR requires a minimum stack depth of 2.")
         first_operand = self.stack.pop()
@@ -301,8 +319,6 @@ class BooleanTypeChecker(TypeChecker):
             )
 
 
-
-
 class IntOrNatTypeChecker(TypeChecker):
     def typecheck_neg(self):
         self.stack.assert_min_length(1, "ADD requires a minimum stack depth of 2.")
@@ -317,7 +333,6 @@ class IntOrNatTypeChecker(TypeChecker):
                 [number],
             )
 
-
     def typecheck_abs(self):
         self.stack.assert_min_length(1, "You cannot call ABS on an empty stack.")
         number = self.stack.get_at_depth(0)
@@ -331,7 +346,6 @@ class IntOrNatTypeChecker(TypeChecker):
                 [number],
             )
 
-
     def typecheck_is_nat(self):
         self.stack.assert_min_length(1, "You cannot call IS_NAT on an empty stack.")
         number = self.stack.get_at_depth(0)
@@ -345,7 +359,6 @@ class IntOrNatTypeChecker(TypeChecker):
                 [number],
             )
 
-
     def typecheck_int(self):
         self.stack.assert_min_length(1, "You cannot call INT on an empty stack.")
         number = self.stack.get_at_depth(0)
@@ -359,7 +372,6 @@ class IntOrNatTypeChecker(TypeChecker):
                 [number],
             )
 
-
     def typecheck_add(self):
         self.stack.assert_min_length(2, "ADD requires a minimum stack depth of 2.")
         first_operand = self.stack.get_at_depth(0)
@@ -531,7 +543,9 @@ class UnionTypeChecker(TypeChecker):
     def typecheck_left(self, instruction: Instr):
         self.stack.assert_min_length(1, "LEFT requires a non empty stack.")
         instruction.assert_n_args(1, "LEFT requires a type as unique argument.")
-        instruction.assert_arg_type(0, t.Type, "LEFT requires a type as unique argument.")
+        instruction.assert_arg_type(
+            0, t.Type, "LEFT requires a type as unique argument."
+        )
 
         left_type = self.stack.get_at_depth(0)
         right_type = instruction.args[0]
@@ -541,7 +555,9 @@ class UnionTypeChecker(TypeChecker):
     def typecheck_right(self, instruction: Instr):
         self.stack.assert_min_length(1, "RIGHT requires a non empty stack.")
         instruction.assert_n_args(1, "RIGHT requires a type as unique argument.")
-        instruction.assert_arg_type(0, t.Type, "RIGHT requires a type as unique argument.")
+        instruction.assert_arg_type(
+            0, t.Type, "RIGHT requires a type as unique argument."
+        )
 
         right_type = self.stack.get_at_depth(0)
         left_type = instruction.args[0]
@@ -558,6 +574,7 @@ class UnionTypeChecker(TypeChecker):
                 temp_stack.push_type(union.right_type)
 
             return temp_stack
+
         generic_if("IF_LEFT", instruction, t.Or, self.stack, prepare_stack)
 
 
@@ -605,7 +622,9 @@ class OptionTypeChecker(TypeChecker):
 
     def typecheck_none(self, instruction: Instr):
         instruction.assert_n_args(1, "NONE requires a type as unique argument.")
-        instruction.assert_arg_type(0, t.Type, "NONE requires a type as unique argument.")
+        instruction.assert_arg_type(
+            0, t.Type, "NONE requires a type as unique argument."
+        )
         self.stack.push_type(t.Option(instruction.args[0]))
 
     def typecheck_compare(self):
@@ -632,8 +651,10 @@ class OptionTypeChecker(TypeChecker):
                 temp_stack.push_type(optional.option_type)
 
             return temp_stack
+
         generic_if("IF_NONE", instruction, t.Option, self.stack, prepare_stack)
 
+
 class StringTypeChecker(TypeChecker):
     def typecheck_concat(self):
         self.stack.assert_min_length(2, "CONCAT requires a minimum stack depth of 2.")
@@ -811,7 +832,9 @@ class PairTypeChecker(TypeChecker):
         self.stack.push_type(pair.car)
 
     def typecheck_pair_n(self, n: int):
-        self.assert_valid_michelson(n >= 2, "PAIR n requires `n` to be strictly geater than 1.")
+        self.assert_valid_michelson(
+            n >= 2, "PAIR n requires `n` to be strictly geater than 1."
+        )
         self.stack.assert_min_length(n, "PAIR n requires a stack of minimum length n.")
 
         args = []
@@ -889,7 +912,9 @@ class BytesTypeChecker(TypeChecker):
         self.stack.assert_min_length(1, "UNPACK requires a non empty stack.")
 
         instruction.assert_n_args(1, "UNPACK requires a type as unique argument.")
-        instruction.assert_arg_type(0, t.Type, "UNPACK requires a type as unique argument.")
+        instruction.assert_arg_type(
+            0, t.Type, "UNPACK requires a type as unique argument."
+        )
         unpack_type = t.Option(instruction.args[0])
 
         self.stack.pop()
@@ -1022,10 +1047,13 @@ class CryptographicPrimitivesTypeChecker(TypeChecker):
                 [element],
             )
 
+
 class SetTypeChecker(TypeChecker):
     def typecheck_empty_set(self, instruction: Instr):
         if len(instruction.args) != 1:
-            raise InvalidMichelsonException("EMPTY_SET requires a type as only argument")
+            raise InvalidMichelsonException(
+                "EMPTY_SET requires a type as only argument"
+            )
 
         for type_ in instruction.args:
             if not isinstance(type_, t.Type):
@@ -1088,7 +1116,6 @@ class SetTypeChecker(TypeChecker):
             )
 
 
-
 class ListTypeChecker(TypeChecker):
     def typecheck_empty_list(self, instruction: Instr):
         if len(instruction.args) != 1:
@@ -1142,7 +1169,7 @@ class ListTypeChecker(TypeChecker):
 
         self.assert_valid_michelson(
             len(instruction.args) == 1 and isinstance(instruction.args[0], list),
-            "ITER must have a single argument that is a list of instructions."
+            "ITER must have a single argument that is a list of instructions.",
         )
         iter_instructions = instruction.args[0]
 
@@ -1153,7 +1180,9 @@ class ListTypeChecker(TypeChecker):
             self.stack.push_type(list_type.element_type)
             typechecker.typecheck(self.stack, iter_instructions)
 
-            self.stack.assert_length(old_length, "The body of an ITER must not change the stack length.")
+            self.stack.assert_length(
+                old_length, "The body of an ITER must not change the stack length."
+            )
         else:
             raise E.StackTopTypeException(
                 "ITER",
@@ -1235,7 +1264,6 @@ class MapTypeChecker(TypeChecker):
                 [map_type],
             )
 
-
     def typecheck_update_map(self):
         self.stack.assert_min_length(
             3, "Cannot call UPDATE on a stack of length less than 2."
@@ -1249,7 +1277,7 @@ class MapTypeChecker(TypeChecker):
                 raise E.MapValueTypeException(
                     f"{value_type}",
                     f"{t.Option(map_type.value_type)}",
-                    f"Trying to update a `{map_type}` with a non optional of type `{value_type}`."
+                    f"Trying to update a `{map_type}` with a non optional of type `{value_type}`.",  # noqa E501
                 )
             if key_type != map_type.key_type:
                 raise E.MapKeyTypeException(
@@ -1288,12 +1316,13 @@ class MapTypeChecker(TypeChecker):
 class TransactionTypeChecker(TypeChecker):
     def typecheck_contract(self, instruction: Instr):
         self.assert_valid_michelson(
-            len(instruction.args) == 1
-            and isinstance(instruction.args[0], t.Type),
-            "CONTRACT takes the contract type as single argument"
+            len(instruction.args) == 1 and isinstance(instruction.args[0], t.Type),
+            "CONTRACT takes the contract type as single argument",
         )
         cast_type = instruction.args[0]
-        self.stack.assert_min_length(1, "CONTRACT requires a minimum stack length of 1.")
+        self.stack.assert_min_length(
+            1, "CONTRACT requires a minimum stack length of 1."
+        )
         address = self.stack.pop()
         if address != t.Address():
             raise E.StackTopTypeException(
@@ -1304,7 +1333,9 @@ class TransactionTypeChecker(TypeChecker):
         self.stack.push_type(t.Option(t.Contract(cast_type)))
 
     def typecheck_transfer_tokens(self):
-        self.stack.assert_min_length(3, "TRANSFER_TOKENS requires a minimum stack length of 3.")
+        self.stack.assert_min_length(
+            3, "TRANSFER_TOKENS requires a minimum stack length of 3."
+        )
         arg_type = self.stack.pop()
         mutez = self.stack.pop()
         contract = self.stack.pop()
@@ -1323,7 +1354,11 @@ class TransactionTypeChecker(TypeChecker):
                 [contract, mutez, arg_type],
             )
 
-        self.assert_type(mutez, t.Mutez(), "Type of second topmost stack element when calling TRANSFER_TOKENS should be mutez.")
+        self.assert_type(
+            mutez,
+            t.Mutez(),
+            "Type of second topmost stack element when calling TRANSFER_TOKENS should be mutez.",  # noqa: E501
+        )
 
         self.stack.push_type(t.Operation())
 
@@ -1338,8 +1373,12 @@ class StackManipulationTypeChecker(TypeChecker):
         function_stack = StackType([arg_type])
         typechecker.typecheck(function_stack, function_body)
 
-        function_stack.assert_length(1, "The body of a LAMBDA must return a stack of 1 element")
-        function_stack.assert_top_type([return_type], "LAMBDA body does not return type matching its signature.")
+        function_stack.assert_length(
+            1, "The body of a LAMBDA must return a stack of 1 element"
+        )
+        function_stack.assert_top_type(
+            [return_type], "LAMBDA body does not return type matching its signature."
+        )
 
         self.stack.push_type(t.FunctionPrototype(arg_type, return_type, function_body))
 
@@ -1365,7 +1404,11 @@ class StackManipulationTypeChecker(TypeChecker):
     def typecheck_dug(self, instruction: Instr):
         if not len(instruction.args):
             raise InvalidMichelsonException("DUG takes an argument")
-        if len(instruction.args) and isinstance(instruction.args[0], int) and instruction.args[0] >= 0:
+        if (
+            len(instruction.args)
+            and isinstance(instruction.args[0], int)
+            and instruction.args[0] >= 0
+        ):
             depth = instruction.args[0]
             if not depth:
                 return
@@ -1384,7 +1427,10 @@ class StackManipulationTypeChecker(TypeChecker):
         instruction.assert_n_args(2, "PUSH requires 2 arguments.")
         arg_type = instruction.args[0]
         arg_value = instruction.args[1]
-        update_stack = lambda: self.stack.push_type(instruction.args[0])
+
+        def update_stack():
+            return self.stack.push_type(instruction.args[0])
+
         if arg_type == t.Int() and isinstance(arg_value, int):
             update_stack()
         elif arg_type == t.Nat() and isinstance(arg_value, int):
@@ -1438,7 +1484,9 @@ class ControlStructuresTypeChecker(TypeChecker):
             depth = instruction.args[0]
             instructions = instruction.args[1]
 
-            self.stack.assert_min_length(depth, "Cannot call DIP n on a stack smaller than n")
+            self.stack.assert_min_length(
+                depth, "Cannot call DIP n on a stack smaller than n"
+            )
 
             self.stack.protect_stack_top(depth)
             typecheck(init_stack_type=self.stack, instructions=instructions)
@@ -1468,10 +1516,17 @@ class ControlStructuresTypeChecker(TypeChecker):
         stack_exception = E.StackTopTypeException(
             "APPLY",
             [t.Contract(t.TypeVar()), t.Mutez(), t.TypeVar()],
-            [t.TypeVar("T"), t.FunctionPrototype(t.Pair(t.TypeVar("T"), t.TypeVar("U")), t.TypeVar("V"))],
+            [
+                t.TypeVar("T"),
+                t.FunctionPrototype(
+                    t.Pair(t.TypeVar("T"), t.TypeVar("U")), t.TypeVar("V")
+                ),
+            ],
             [partial_arg_type, lambda_type],
         )
-        if not isinstance(lambda_type, t.FunctionPrototype) or not isinstance(lambda_type.arg_type, t.Record):
+        if not isinstance(lambda_type, t.FunctionPrototype) or not isinstance(
+            lambda_type.arg_type, t.Record
+        ):
             raise stack_exception
 
         arg_type = lambda_type.arg_type.get_type()
@@ -1495,33 +1550,77 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             raise E.StackTopTypeException(
                 "MEM",
-                [t.Union([t.Set(t.TypeVar()), t.Dict(t.TypeVar(), t.Universal()), t.BigMap(t.TypeVar(), t.Universal())]), t.TypeVar()],
+                [
+                    t.Union(
+                        [
+                            t.Set(t.TypeVar()),
+                            t.Dict(t.TypeVar(), t.Universal()),
+                            t.BigMap(t.TypeVar(), t.Universal()),
+                        ]
+                    ),
+                    t.TypeVar(),
+                ],
                 [self.stack.get_at_depth(1), self.stack.get_at_depth(0)],
             )
 
     def typecheck_get(self, instruction: Instr):
-        if len(self.stack) >= 2 and isinstance(self.stack.get_at_depth(1), t.Dict) and not len(instruction.args):
-            self.stack.assert_min_length(2, "Get applied to a map requires a stack of minimum length 2.")
+        if (
+            len(self.stack) >= 2
+            and isinstance(self.stack.get_at_depth(1), t.Dict)
+            and not len(instruction.args)
+        ):
+            self.stack.assert_min_length(
+                2, "Get applied to a map requires a stack of minimum length 2."
+            )
             MapTypeChecker(self.stack).typecheck_get_map()
-        elif len(self.stack) >= 2 and isinstance(self.stack.get_at_depth(1), t.BigMap) and not len(instruction.args):
-            self.stack.assert_min_length(2, "Get applied to a map requires a stack of minimum length 2.")
+        elif (
+            len(self.stack) >= 2
+            and isinstance(self.stack.get_at_depth(1), t.BigMap)
+            and not len(instruction.args)
+        ):
+            self.stack.assert_min_length(
+                2, "Get applied to a map requires a stack of minimum length 2."
+            )
             MapTypeChecker(self.stack).typecheck_get_map()
         elif len(self.stack) >= 1 and isinstance(self.stack.get_at_depth(0), t.Pair):
-            self.stack.assert_min_length(1, "Get applied to a pair requires a stack of minimum length 1.")
-            instruction.assert_n_args(1, "GET applied to a Pair requires an integer argument.")
-            instruction.assert_arg_type(0, int, "GET applied to a Pair requires an integer argument.")
+            self.stack.assert_min_length(
+                1, "Get applied to a pair requires a stack of minimum length 1."
+            )
+            instruction.assert_n_args(
+                1, "GET applied to a Pair requires an integer argument."
+            )
+            instruction.assert_arg_type(
+                0, int, "GET applied to a Pair requires an integer argument."
+            )
             PairTypeChecker(self.stack).typecheck_get_n(instruction.args[0])
         elif len(self.stack) >= 1 and isinstance(self.stack.get_at_depth(0), t.Record):
-            self.stack.assert_min_length(1, "Get applied to a pair requires a stack of minimum length 1.")
-            instruction.assert_n_args(1, "GET applied to a Pair requires an integer argument.")
-            instruction.assert_arg_type(0, int, "GET applied to a Pair requires an integer argument.")
+            self.stack.assert_min_length(
+                1, "Get applied to a pair requires a stack of minimum length 1."
+            )
+            instruction.assert_n_args(
+                1, "GET applied to a Pair requires an integer argument."
+            )
+            instruction.assert_arg_type(
+                0, int, "GET applied to a Pair requires an integer argument."
+            )
             record = self.stack.pop()
             self.stack.push_type(record.get_type())
             PairTypeChecker(self.stack).typecheck_get_n(instruction.args[0])
         else:
-            get_on_iterable_allowed_stacks = [t.Union([t.List(t.TypeVar()), t.Dict(t.TypeVar(), t.Universal()), t.BigMap(t.TypeVar(), t.Universal())]), t.TypeVar()]
+            get_on_iterable_allowed_stacks = [
+                t.Union(
+                    [
+                        t.List(t.TypeVar()),
+                        t.Dict(t.TypeVar(), t.Universal()),
+                        t.BigMap(t.TypeVar(), t.Universal()),
+                    ]
+                ),
+                t.TypeVar(),
+            ]
             get_on_pair_allowed_stacks = [t.Pair(t.Universal(), t.Universal())]
-            allowed_stacks = t.Union([get_on_iterable_allowed_stacks, get_on_pair_allowed_stacks])
+            allowed_stacks = t.Union(
+                [get_on_iterable_allowed_stacks, get_on_pair_allowed_stacks]
+            )
             raise E.StackTopTypeException(
                 "GET",
                 allowed_stacks,
@@ -1529,24 +1628,63 @@ class MichelsonTypeChecker(TypeChecker):
             )
 
     def typecheck_update(self, instruction: Instr):
-        if len(self.stack) >= 3 and isinstance(self.stack.get_at_depth(2), t.Dict) and not len(instruction.args):
-            self.stack.assert_min_length(3, "UPDATE applied to a map requires a stack of minimum length 3.")
+        if (
+            len(self.stack) >= 3
+            and isinstance(self.stack.get_at_depth(2), t.Dict)
+            and not len(instruction.args)
+        ):
+            self.stack.assert_min_length(
+                3, "UPDATE applied to a map requires a stack of minimum length 3."
+            )
             MapTypeChecker(self.stack).typecheck_update_map()
-        elif len(self.stack) >= 3 and isinstance(self.stack.get_at_depth(2), t.BigMap) and not len(instruction.args):
-            self.stack.assert_min_length(3, "UPDATE applied to a map requires a stack of minimum length 3.")
+        elif (
+            len(self.stack) >= 3
+            and isinstance(self.stack.get_at_depth(2), t.BigMap)
+            and not len(instruction.args)
+        ):
+            self.stack.assert_min_length(
+                3, "UPDATE applied to a map requires a stack of minimum length 3."
+            )
             MapTypeChecker(self.stack).typecheck_update_map()
-        elif len(self.stack) >= 3 and isinstance(self.stack.get_at_depth(2), t.Set) and not len(instruction.args):
-            self.stack.assert_min_length(3, "UPDATE applied to a set requires a stack of minimum length 3.")
+        elif (
+            len(self.stack) >= 3
+            and isinstance(self.stack.get_at_depth(2), t.Set)
+            and not len(instruction.args)
+        ):
+            self.stack.assert_min_length(
+                3, "UPDATE applied to a set requires a stack of minimum length 3."
+            )
             SetTypeChecker(self.stack).typecheck_update_set()
-        elif len(self.stack) >= 2 and isinstance(self.stack.get_at_depth(1), t.Pair) and len(self.stack) >= 2 and len(instruction.args) == 1:
-            self.stack.assert_min_length(1, "UPDATE applied to a pair requires a stack of minimum length 2.")
-            instruction.assert_n_args(1, "UPDATE applied to a Pair requires an integer argument.")
-            instruction.assert_arg_type(0, int, "UPDATE applied to a Pair requires an integer argument.")
+        elif (
+            len(self.stack) >= 2
+            and isinstance(self.stack.get_at_depth(1), t.Pair)
+            and len(self.stack) >= 2
+            and len(instruction.args) == 1
+        ):
+            self.stack.assert_min_length(
+                1, "UPDATE applied to a pair requires a stack of minimum length 2."
+            )
+            instruction.assert_n_args(
+                1, "UPDATE applied to a Pair requires an integer argument."
+            )
+            instruction.assert_arg_type(
+                0, int, "UPDATE applied to a Pair requires an integer argument."
+            )
             PairTypeChecker(self.stack).typecheck_update_n(instruction.args[0])
-        elif len(self.stack) >= 2 and isinstance(self.stack.get_at_depth(1), t.Record) and len(instruction.args) == 1:
-            self.stack.assert_min_length(1, "UPDATE applied to a pair requires a stack of minimum length 2.")
-            instruction.assert_n_args(1, "UPDATE applied to a Pair requires an integer argument.")
-            instruction.assert_arg_type(0, int, "UPDATE applied to a Pair requires an integer argument.")
+        elif (
+            len(self.stack) >= 2
+            and isinstance(self.stack.get_at_depth(1), t.Record)
+            and len(instruction.args) == 1
+        ):
+            self.stack.assert_min_length(
+                1, "UPDATE applied to a pair requires a stack of minimum length 2."
+            )
+            instruction.assert_n_args(
+                1, "UPDATE applied to a Pair requires an integer argument."
+            )
+            instruction.assert_arg_type(
+                0, int, "UPDATE applied to a Pair requires an integer argument."
+            )
             argument = self.stack.pop()
             record = self.stack.pop()
             self.stack.push_type(record.get_type())
@@ -1554,15 +1692,19 @@ class MichelsonTypeChecker(TypeChecker):
             PairTypeChecker(self.stack).typecheck_update_n(instruction.args[0])
         else:
             get_on_iterable_allowed_stacks = [
-                t.Union([
-                    t.Dict(t.TypeVar("T"), t.Universal("U")),
-                    t.BigMap(t.TypeVar("T"), t.Universal("U"))
-                ]),
+                t.Union(
+                    [
+                        t.Dict(t.TypeVar("T"), t.Universal("U")),
+                        t.BigMap(t.TypeVar("T"), t.Universal("U")),
+                    ]
+                ),
                 t.TypeVar("T"),
                 t.TypeVar("U"),
             ]
             get_on_pair_allowed_stacks = [t.Pair(t.Universal(), t.Universal())]
-            allowed_stacks = t.Union([get_on_iterable_allowed_stacks, get_on_pair_allowed_stacks])
+            allowed_stacks = t.Union(
+                [get_on_iterable_allowed_stacks, get_on_pair_allowed_stacks]
+            )
             raise E.StackTopTypeException(
                 "UPDATE",
                 allowed_stacks,
@@ -1582,7 +1724,16 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             raise E.StackTopTypeException(
                 "SIZE",
-                [t.Union([t.List(t.Universal()), t.Set(t.Universal()), t.Dict(t.Universal(), t.Universal()), t.Dict(t.Universal(), t.Universal())])],
+                [
+                    t.Union(
+                        [
+                            t.List(t.Universal()),
+                            t.Set(t.Universal()),
+                            t.Dict(t.Universal(), t.Universal()),
+                            t.Dict(t.Universal(), t.Universal()),
+                        ]
+                    )
+                ],
                 [self.stack.get_at_depth(0)],
             )
 
@@ -1601,7 +1752,6 @@ class MichelsonTypeChecker(TypeChecker):
                 [operand_a, operand_b],
             )
 
-
     def typecheck_slice(self):
         self.stack.assert_min_length(2, "SLICE requires a stack of length at least 2.")
         offset = self.stack.get_at_depth(0)
@@ -1618,9 +1768,10 @@ class MichelsonTypeChecker(TypeChecker):
                 [element_type, length, offset],
             )
 
-
     def typecheck_compare(self):
-        self.stack.assert_min_length(2, "COMPARE requires a stack of length at least 2.")
+        self.stack.assert_min_length(
+            2, "COMPARE requires a stack of length at least 2."
+        )
         operand_a = self.stack.get_at_depth(0)
         operand_b = self.stack.get_at_depth(1)
         if isinstance(operand_a, t.String) and isinstance(operand_b, t.String):
@@ -1642,34 +1793,40 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             raise E.OperandException(
                 "COMPARE",
-                [t.Int(), t.Nat(), t.String(), t.Mutez(), t.Bytes(), t.Address(), t.Datetime()],
+                [
+                    t.Int(),
+                    t.Nat(),
+                    t.String(),
+                    t.Mutez(),
+                    t.Bytes(),
+                    t.Address(),
+                    t.Datetime(),
+                ],
                 [operand_b, operand_a],
             )
 
-
     def typecheck_pair(self, instruction: Instr):
         if len(instruction.args) and isinstance(instruction.args[0], int):
             PairTypeChecker(self.stack).typecheck_pair_n(instruction.args[0])
         else:
             PairTypeChecker(self.stack).typecheck_pair()
 
-
     def typecheck_contract(self, contract: Contract):
         parameter_type = contract.get_parameter_type()
         storage_type = contract.get_storage_type()
-        body_instructions = contract.instructions + [
-            contract.get_contract_body()
-        ]
+        body_instructions = contract.instructions + [contract.get_contract_body()]
 
         init_stack = StackType([t.Pair(car=parameter_type, cdr=storage_type)])
         self.typecheck(init_stack, body_instructions)
         self.stack.assert_length(1, "The contract must return a stack of length 1.")
         if isinstance(storage_type, t.Record):
             storage_type = storage_type.get_type()
-        if self.stack != StackType([t.Pair(car=t.List(t.Operation()), cdr=storage_type)]):
+        if self.stack != StackType(
+            [t.Pair(car=t.List(t.Operation()), cdr=storage_type)]
+        ):
             raise E.ContractReturnTypeException(
                 self.stack,
-                StackType([t.Pair(car=t.List(t.Operation()), cdr=storage_type)])
+                StackType([t.Pair(car=t.List(t.Operation()), cdr=storage_type)]),
             )
 
     def typecheck_mul(self):
@@ -1689,7 +1846,6 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             IntOrNatTypeChecker(self.stack).typecheck_ediv()
 
-
     def typecheck_add(self):
         self.stack.assert_min_length(2, "ADD requires a stack of length at least 2.")
         operand_a = self.stack.get_at_depth(0)
@@ -1699,7 +1855,6 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             IntOrNatTypeChecker(self.stack).typecheck_add()
 
-
     def typecheck_sub(self):
         self.stack.assert_min_length(2, "SUB requires a stack of length at least 2.")
         operand_a = self.stack.get_at_depth(0)
@@ -1744,11 +1899,10 @@ class MichelsonTypeChecker(TypeChecker):
         else:
             IntOrNatTypeChecker(self.stack).typecheck_not()
 
-
     def typecheck(
-            self,
-            init_stack_type: Optional[StackType] = None,
-            instructions: Optional[List[Instr]] = None,
+        self,
+        init_stack_type: Optional[StackType] = None,
+        instructions: Optional[List[Instr]] = None,
     ):
         if init_stack_type is None:
             self.stack.reset()
@@ -1760,7 +1914,9 @@ class MichelsonTypeChecker(TypeChecker):
 
         for instruction in instructions:
             if not isinstance(instruction, Instr):
-                raise InvalidMichelsonException("Cannot typecheck: not a Michelson instruction")
+                raise InvalidMichelsonException(
+                    "Cannot typecheck: not a Michelson instruction"
+                )
             elif instruction.name == "FAILWITH":
                 self.stack = StackType([t.Universal()])
                 return
@@ -1783,7 +1939,9 @@ class MichelsonTypeChecker(TypeChecker):
             elif instruction.name == "APPLY":
                 ControlStructuresTypeChecker(self.stack).typecheck_apply()
             elif instruction.name == "DIP":
-                ControlStructuresTypeChecker(self.stack).typecheck_dip(instruction, self.typecheck)
+                ControlStructuresTypeChecker(self.stack).typecheck_dip(
+                    instruction, self.typecheck
+                )
             elif instruction.name == "IF":
                 ControlStructuresTypeChecker(self.stack).typecheck_if(instruction)
             elif instruction.name == "LAMBDA":
@@ -1899,8 +2057,8 @@ class MichelsonTypeChecker(TypeChecker):
             elif instruction.name == "COMMENT":
                 pass
             else:
-                breakpoint()
                 raise NotImplementedError()
 
-            logging.debug("\n\n" + str(instruction).ljust(12) + "\n" + str(self.stack) + "\n")
-
+            logging.debug(
+                "\n\n" + str(instruction).ljust(12) + "\n" + str(self.stack) + "\n"
+            )
