@@ -1,17 +1,17 @@
 import ast
 from typing import Any, List, Union
-from dataclasses import dataclass
-
-import unittest
-
-import pymich.utils.exceptions as E
-
 
 
 def _is_view(node) -> bool:
     """A contract method is considered a view if has a return type annotation
     and does not start with an underscore (_)"""
-    if type(node) == ast.FunctionDef and node.name[0] != "_" and node.returns is not None:
+    is_fundef = type(node) == ast.FunctionDef
+    if not is_fundef:
+        return False
+
+    starts_with_underscore = node.name[0] != "_"
+    returns_none = node.returns is not None
+    if starts_with_underscore and returns_none:
         for body_el in node.body:
             if type(body_el) == ast.Return:
                 return True
@@ -34,7 +34,7 @@ def make_dataclass(name, arguments_spec):
             )
             for argument_name, argument_type in arguments_spec.items()
         ],
-        decorator_list=[ast.Name(id='dataclass', ctx=ast.Load())]
+        decorator_list=[ast.Name(id="dataclass", ctx=ast.Load())],
     )
 
 
@@ -53,19 +53,20 @@ class RewriteViews(ast.NodeTransformer):
         transaction(__callback__, Mutez(0), self.total_supply)
 
     """
+
     def _transform_return(self, node: ast.Return) -> ast.Call:
         return ast.Call(
-            func=ast.Name(id='transaction', ctx=ast.Load()),
+            func=ast.Name(id="transaction", ctx=ast.Load()),
             args=[
-                ast.Name(id='__callback__', ctx=ast.Load()),
+                ast.Name(id="__callback__", ctx=ast.Load()),
                 ast.Call(
-                    func=ast.Name(id='Mutez', ctx=ast.Load()),
+                    func=ast.Name(id="Mutez", ctx=ast.Load()),
                     args=[ast.Constant(value=0, kind=None)],
-                    keywords=[]
+                    keywords=[],
                 ),
-                node.value
+                node.value,
             ],
-            keywords=[]
+            keywords=[],
         )
 
     def _transform_block(self, nodes) -> List[Any]:
@@ -81,11 +82,9 @@ class RewriteViews(ast.NodeTransformer):
     def _expand_view(self, node: ast.FunctionDef) -> Any:
         # add `contract_callback: Contract[return_type]` to method parameter
         callback_annotation = ast.Subscript(
-            value=ast.Name(id='Contract', ctx=ast.Load()),
-            slice=ast.Index(
-                value=node.returns
-            ),
-            ctx=ast.Load()
+            value=ast.Name(id="Contract", ctx=ast.Load()),
+            slice=ast.Index(value=node.returns),
+            ctx=ast.Load(),
         )
         callback_argument = ast.arg(arg="__callback__", annotation=callback_annotation)
         node.args.args.append(callback_argument)
@@ -96,7 +95,6 @@ class RewriteViews(ast.NodeTransformer):
         # transform all return expressions into `transaction` function call
         node.body = self._transform_block(node.body)
 
-
         return node
 
     def visit_ClassDef(self, node: ast.ClassDef) -> Any:
@@ -153,20 +151,27 @@ class TuplifyFunctionArguments(ast.NodeTransformer):
 
         # skip class instantiations and functions of 1 argument
         if len(arguments) > 1:
-            ### generate argument dataclass
+            # generate argument dataclass
             arguments_spec = {
                 argument_node.arg: (argument_node.annotation, node.lineno)
                 for argument_node in arguments
             }
             param_dataclass_name = node.name + "Param"
-            self.dataclasses.append(make_dataclass(param_dataclass_name, arguments_spec))
+            self.dataclasses.append(
+                make_dataclass(param_dataclass_name, arguments_spec)
+            )
 
             # tuplify arguments
             param_name = node.name + "__param"
 
             self.env[node.name] = param_dataclass_name
 
-            node.args.args = [ast.arg(arg=param_name, annotation=ast.Name(id=param_dataclass_name, ctx=ast.Load()))]
+            node.args.args = [
+                ast.arg(
+                    arg=param_name,
+                    annotation=ast.Name(id=param_dataclass_name, ctx=ast.Load()),
+                )
+            ]
 
             # destructure tuplified arguments
             prologue_body_instructions = [
@@ -175,9 +180,10 @@ class TuplifyFunctionArguments(ast.NodeTransformer):
                     value=ast.Attribute(
                         value=ast.Name(id=param_name, ctx=ast.Load()),
                         attr=attr_name,
-                        ctx=ast.Load()
+                        ctx=ast.Load(),
                     ),
-                    type_comment=None)
+                    type_comment=None,
+                )
                 for attr_name in arguments_spec.keys()
             ]
 
@@ -226,12 +232,13 @@ class TuplifyFunctionArguments(ast.NodeTransformer):
 
         return False
 
-
     def visit_Call(self, node: ast.Call) -> Any:
         if self.check_if_stdlib_method(node):
             return node
 
-        if self.check_if_stdlib_function(node) or self.check_if_stdlib_constructor(node):
+        if self.check_if_stdlib_function(node) or self.check_if_stdlib_constructor(
+            node
+        ):
             return node
 
         try:
@@ -245,17 +252,22 @@ class TuplifyFunctionArguments(ast.NodeTransformer):
 
         fun_name = node.func.id
 
-        if len(node.args) > 1 and fun_name not in self.defined_class_names and fun_name != "transaction":
-            #if fun_name not in self.env:
-            #    raise E.FunctionNameException(fun_name, node.lineno)
+        if (
+            len(node.args) > 1
+            and fun_name not in self.defined_class_names
+            and fun_name != "transaction"
+        ):
+            # if fun_name not in self.env:
+            #     raise E.FunctionNameException(fun_name, node.lineno)
             try:
                 node.args = [
                     ast.Call(
                         func=ast.Name(id=self.env[fun_name], ctx=ast.Load()),
                         args=[self.visit(arg) for arg in node.args],
-                        keywords=[])
+                        keywords=[],
+                    )
                 ]
-            except:
+            except Exception:
                 pass
         else:
             node.args = [self.visit(arg) for arg in node.args]
@@ -278,14 +290,18 @@ class AssignAllFunctionCalls(ast.NodeTransformer):
     def visit_Expr(self, node: ast.Expr) -> Any:
         """Funcalls which's return value are not assigned are wrapped in an ast.Expr"""
         if type(node.value) == ast.Call:
-            if type(node.value.func) == ast.Name and node.value.func.id == "transaction":
+            if (
+                type(node.value.func) == ast.Name
+                and node.value.func.id == "transaction"
+            ):
                 pass
             else:
                 call_node = node.value
                 return ast.Assign(
-                    targets=[ast.Name(id='__placeholder__', ctx=ast.Store())],
+                    targets=[ast.Name(id="__placeholder__", ctx=ast.Store())],
                     value=call_node,
-                    type_comment=None)
+                    type_comment=None,
+                )
 
         return node
 
@@ -306,7 +322,7 @@ class RemoveSelfArgFromMethods(ast.NodeTransformer):
     """
 
     def remove_first_untyped_arg(self, node: ast.FunctionDef) -> Any:
-        if len(node.args.args) and node.args.args[0].annotation == None:
+        if len(node.args.args) and node.args.args[0].annotation is None:
             del node.args.args[0]
 
         return node
@@ -324,11 +340,8 @@ class RemoveSelfArgFromMethods(ast.NodeTransformer):
 
 class ExpandStorageInEntrypoints(ast.NodeTransformer):
     def visit_Attribute(self, node: ast.Attribute) -> Union[ast.Name, ast.Attribute]:
-        if (
-            isinstance(node.value, ast.Name)
-            and node.value.id == "self"
-        ):
-            node.value.id = '__STORAGE__'
+        if isinstance(node.value, ast.Name) and node.value.id == "self":
+            node.value.id = "__STORAGE__"
             return node
         else:
             return ast.Attribute(value=self.visit(node.value), attr=node.attr)
@@ -337,7 +350,11 @@ class ExpandStorageInEntrypoints(ast.NodeTransformer):
 def is_contract_class_def(node: ast.ClassDef) -> bool:
     if type(node) == ast.ClassDef and node.name == "Contract":
         return True
-    elif type(node) == ast.ClassDef and len(node.bases) and (node.bases[0].id == "Contract" or node.bases[0].id == "BaseContract"):
+    elif (
+        type(node) == ast.ClassDef
+        and len(node.bases)
+        and (node.bases[0].id == "Contract" or node.bases[0].id == "BaseContract")
+    ):
         return True
     return False
 
@@ -372,6 +389,7 @@ class FactorOutStorage(ast.NodeTransformer):
 
             return self.storage
     """
+
     def visit_ClassDef(self, node: ast.ClassDef) -> Any:
         # only expand contract methods
         if is_contract_class_def(node):
@@ -390,12 +408,15 @@ class FactorOutStorage(ast.NodeTransformer):
             for i, body_node in enumerate(node.body):
                 if type(body_node) == ast.AnnAssign:
                     lineno = body_node.lineno
-                    storage_keys_spec[body_node.target.id] = (body_node.annotation, lineno)
+                    storage_keys_spec[body_node.target.id] = (
+                        body_node.annotation,
+                        lineno,
+                    )
                 else:
                     new_node_body.append(body_node)
             node.body = new_node_body
 
-            self.storage_dataclass = make_dataclass('Storage', storage_keys_spec)
+            self.storage_dataclass = make_dataclass("Storage", storage_keys_spec)
 
             # For all methods, update `self.<storage_key>` into `self.storage.<key>`
             # and add return `self.storage`
@@ -403,11 +424,12 @@ class FactorOutStorage(ast.NodeTransformer):
             for body_node in node.body:
                 new_body_node = ExpandStorageInEntrypoints().visit(body_node)
                 if type(body_node) == ast.FunctionDef:
-                    returns_none = isinstance(body_node.returns, ast.Constant) and body_node.returns.value == None
+                    is_constant = isinstance(body_node.returns, ast.Constant)
+                    returns_none = is_constant and body_node.returns.value is None
                     if not body_node.returns or returns_none:
-                        body_node.returns = ast.Name(id='Storage', ctx=ast.Load())
+                        body_node.returns = ast.Name(id="Storage", ctx=ast.Load())
                     return_storage_node = ast.Return(
-                        value=ast.Name(id='__STORAGE__', ctx=ast.Load()),
+                        value=ast.Name(id="__STORAGE__", ctx=ast.Load()),
                     )
                     new_body_node.body.append(return_storage_node)
                 new_body.append(new_body_node)
@@ -415,9 +437,25 @@ class FactorOutStorage(ast.NodeTransformer):
 
             # Create deploy function
             deploy_function_node = ast.FunctionDef(
-                name='deploy',
-                args=ast.arguments(posonlyargs=[], args=[], vararg=None, kwonlyargs=[], kw_defaults=[], kwarg=None, defaults=[]),
-                body=[ast.Return(value=ast.Call(func=ast.Name(id='Storage', ctx=ast.Load()), args=[], keywords=[]))],
+                name="deploy",
+                args=ast.arguments(
+                    posonlyargs=[],
+                    args=[],
+                    vararg=None,
+                    kwonlyargs=[],
+                    kw_defaults=[],
+                    kwarg=None,
+                    defaults=[],
+                ),
+                body=[
+                    ast.Return(
+                        value=ast.Call(
+                            func=ast.Name(id="Storage", ctx=ast.Load()),
+                            args=[],
+                            keywords=[],
+                        )
+                    )
+                ],
                 decorator_list=[],
                 returns=None,
                 type_comment=None,
@@ -449,7 +487,9 @@ class HandleNoArgEntrypoints(ast.NodeTransformer):
 
     def visit_FunctionDef(self, node: ast.FunctionDef) -> Any:
         if not len(node.args.args) and node.name != "deploy":
-            node.args.args.append(ast.arg(arg='p', annotation=ast.Name(id='unit', ctx=ast.Load())))
+            node.args.args.append(
+                ast.arg(arg="p", annotation=ast.Name(id="unit", ctx=ast.Load()))
+            )
 
         return node
 
@@ -479,15 +519,12 @@ class RewriteOperations(ast.NodeTransformer):
             and node.attr == "ops"
         ):
             return ast.Name(id="__OPERATIONS__", ctx=node.ctx)
-        elif (
-            isinstance(node.value, ast.Attribute)
-        ):
+        elif isinstance(node.value, ast.Attribute):
             return ast.Attribute(value=self.visit(node.value), attr=node.attr)
         else:
             return node
 
 
-
 class PlaceBackStorageDataclass(ast.NodeTransformer):
     def __init__(self, storage_dataclass: ast.ClassDef):
         super().__init__()
@@ -501,32 +538,3 @@ class PlaceBackStorageDataclass(ast.NodeTransformer):
 
         node.body.insert(el_number, self.storage_dataclass)
         return node
-
-
-def macro_expander(source_ast, std_lib):
-    factor_out_storage = FactorOutStorage()
-    tuplify_function_arguments = TuplifyFunctionArguments(std_lib)
-
-    frontend_passes = [
-        RewriteOperations(),
-        RewriteViews(),
-        factor_out_storage,
-        RemoveSelfArgFromMethods(),
-        AssignAllFunctionCalls(),
-        HandleNoArgEntrypoints(),
-        FrontendCompiler(),
-        tuplify_function_arguments,
-    ]
-
-    new_ast = source_ast
-    for frontend_pass in frontend_passes:
-        new_ast = frontend_pass.visit(new_ast)
-        new_ast = ast.fix_missing_locations(new_ast)
-
-    new_ast.body = tuplify_function_arguments.dataclasses + new_ast.body
-    if hasattr(factor_out_storage, 'storage_dataclass'):
-        new_ast = PlaceBackStorageDataclass(factor_out_storage.storage_dataclass).visit(new_ast)
-
-    new_ast = ast.fix_missing_locations(new_ast)
-    return new_ast
-
