@@ -1,5 +1,5 @@
 import ast
-from typing import List, Tuple, Callable
+from typing import List, Tuple
 from pymich.utils.compiler_stdlib import StdLib
 
 
@@ -18,7 +18,9 @@ class Helpers:
         self.counter += 1
         return self.make_tmp_var_name(self.counter)
 
-    def refactor_into_variable(self, node: ast.stmt) -> Tuple[ast.Assign, ast.Name, str]:
+    def refactor_into_variable(
+        self, node: ast.stmt
+    ) -> Tuple[ast.Assign, ast.Name, str]:
         tmp_var_name = self.get_tmp_var_name()
         assign_ast = ast.Assign(
             targets=[ast.Name(id=tmp_var_name, ctx=ast.Store())],
@@ -47,10 +49,10 @@ class Helpers:
                 return True
         # handle `-1`
         if (
-                isinstance(node, ast.UnaryOp)
-                and isinstance(node.op, ast.USub)
-                and isinstance(node.operand, ast.Constant)
-            ):
+            isinstance(node, ast.UnaryOp)
+            and isinstance(node.op, ast.USub)
+            and isinstance(node.operand, ast.Constant)
+        ):
             return True
 
         return False
@@ -72,34 +74,25 @@ def get_empty_list(x: ast.stmt) -> List[ast.stmt]:
 
 class ThreeAddressCodePass1:
     """Three address code assignment LHS"""
+
     def __init__(self, helpers: Helpers):
         self.helpers = helpers
 
-    def _get_set_nested_expr_spec(self, node, spec = None):
+    def _get_set_nested_expr_spec(self, node, spec=None):
         if spec is None:
             spec = []
 
         def var_spec(var_name):
-            return {
-                "type": "FETCH",
-                "value": var_name.id,
-                "lineno": var_name.lineno
-            }
+            return {"type": "FETCH", "value": var_name.id, "lineno": var_name.lineno}
 
         def attr_spec(attr_name, lineno):
-            return {
-                "type": "ATTR",
-                "value": {
-                    "key": attr_name
-                },
-                "lineno": lineno
-            }
+            return {"type": "ATTR", "value": {"key": attr_name}, "lineno": lineno}
 
         def subscript_spec(subscript_ast: ast.expr):
             return {
                 "type": "SUBSCRIPT",
                 "value": subscript_ast,
-                "lineno": subscript_ast.lineno
+                "lineno": subscript_ast.lineno,
             }
 
         if type(node) == ast.Name:
@@ -146,7 +139,6 @@ class ThreeAddressCodePass1:
                     value=fetch_var,
                     attr=spec_element["value"]["key"],
                     ctx=ast.Load(),
-
                 )
                 code.append(attribute)
                 fetch_var = self.helpers.assign_last_statement(code)
@@ -172,10 +164,7 @@ class ThreeAddressCodePass1:
                 slice=spec[-1]["value"],
                 ctx=ast.Store(),
             )
-        value_assign = ast.Assign(
-            targets=[target],
-            value=node.value
-        )
+        value_assign = ast.Assign(targets=[target], value=node.value)
         code.append(value_assign)
 
         # decompose backwards
@@ -198,7 +187,7 @@ class ThreeAddressCodePass1:
                 )
                 code.append(assign_ast)
             elif spec_element["type"] == "SUBSCRIPT":
-                target= ast.Subscript(
+                target = ast.Subscript(
                     value=ast.Name(tmp_var_name_assign, ctx=ast.Load()),
                     slice=spec_element["value"],
                 )
@@ -222,8 +211,7 @@ class ThreeAddressCodePass1:
             )
         tmp_var_name = self.helpers.make_tmp_var_name(counter)
         assign = ast.Assign(
-            targets=[target],
-            value=ast.Name(tmp_var_name, ctx=ast.Load())
+            targets=[target], value=ast.Name(tmp_var_name, ctx=ast.Load())
         )
         code.append(assign)
 
@@ -305,6 +293,7 @@ class ThreeAddressCodePass1:
 
 class ThreeAddressCodePass2:
     """Three address code everything else"""
+
     def __init__(self, helpers: Helpers):
         self.helpers = helpers
 
@@ -549,7 +538,7 @@ class ThreeAddressCodePass2:
 
 
 class ThreeAddressEncode:
-    def __init__(self, tmp_var_prefix = "tmp_var_"):
+    def __init__(self, tmp_var_prefix="tmp_var_"):
         self.helpers = Helpers(tmp_var_prefix)
         self.tac_pass_1 = ThreeAddressCodePass1(self.helpers)
         self.tac_pass_2 = ThreeAddressCodePass2(self.helpers)
