@@ -1,5 +1,5 @@
 import ast
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from copy import deepcopy
 from typing import Optional, Sequence
 import pymich.utils.exceptions as E
@@ -24,6 +24,7 @@ class Unknown(Type):
     def __repr__(self):
         return "unknown"
 
+
 class TypeVar(Type):
     def __init__(self, name="T", annotation: Optional[str] = None):
         super().__init__(annotation)
@@ -32,6 +33,7 @@ class TypeVar(Type):
     def __repr__(self):
         return self.name
 
+
 class Option(Type):
     def __init__(self, option_type: Type, annotation: Optional[str] = None):
         super().__init__(annotation)
@@ -45,7 +47,9 @@ class Option(Type):
 
 
 class Or(Type):
-    def __init__(self, left_type: Type, right_type: Type, annotation: Optional[str] = None):
+    def __init__(
+        self, left_type: Type, right_type: Type, annotation: Optional[str] = None
+    ):
         super().__init__(annotation)
         self.left_type = left_type
         self.right_type = right_type
@@ -60,6 +64,7 @@ class Union:
     Indeed, in Michelson, `Or` is a type itself and thus `Int` or `Nat` will not be
     a acceptable types if is the expected type `Or(Int, Nat)`.
     """
+
     def __init__(self, allowed_types: Sequence[Type]):
         self.allowed_types = allowed_types
 
@@ -82,10 +87,12 @@ class Bytes(Type):
     def __repr__(self):
         return "bytes"
 
+
 class PythonInt(Type):
     def __repr__(self):
         return "python_int"
 
+
 class Int(Type):
     def __repr__(self):
         return "int"
@@ -93,6 +100,7 @@ class Int(Type):
     def __eq__(self, o):
         return type(self) == type(o)
 
+
 class Datetime(Type):
     def __repr__(self):
         return "timestamp"
@@ -149,6 +157,7 @@ class Pair(Type):
     car: first element
     cdr: second element
     """
+
     def __init__(self, car: Type, cdr: Type, annotation: Optional[str] = None):
         super().__init__(annotation)
         self.car = car
@@ -161,7 +170,9 @@ class Pair(Type):
 
     def __repr__(self):
         if isinstance(self.car, Pair) and isinstance(self.cdr, Pair):
-            return f"pair({self.car.car}, {self.car.cdr}, {self.cdr.car}, {self.cdr.cdr})"
+            return (
+                f"pair({self.car.car}, {self.car.cdr}, {self.cdr.car}, {self.cdr.cdr})"
+            )
         if isinstance(self.car, Pair):
             return f"pair({self.car.car}, {self.car.cdr}, {self.cdr})"
         if isinstance(self.cdr, Pair):
@@ -191,7 +202,9 @@ class Pair(Type):
                     if isinstance(acc, Pair):
                         acc = acc.cdr
                     else:
-                        raise E.InvalidMichelsonException(f"GET {n} requires a right comb of minimum length {n - 1}")
+                        raise E.InvalidMichelsonException(
+                            f"GET {n} requires a right comb of minimum length {n - 1}"
+                        )
             else:
                 if (n % 2) == 0:
                     return acc
@@ -199,7 +212,9 @@ class Pair(Type):
                     if isinstance(acc, Pair):
                         return acc.car
                     else:
-                        raise E.InvalidMichelsonException(f"GET {n} requires a right comb of minimum length {n}")
+                        raise E.InvalidMichelsonException(
+                            f"GET {n} requires a right comb of minimum length {n}"
+                        )
 
         return acc
 
@@ -217,7 +232,9 @@ class Pair(Type):
                         prev_acc = acc
                         acc = acc.cdr
                     else:
-                        raise E.InvalidMichelsonException(f"UPDATE {n} requires a right comb of minimum length {n - 1}")
+                        raise E.InvalidMichelsonException(
+                            f"UPDATE {n} requires a right comb of minimum length {n - 1}"
+                        )
             else:
                 if (n % 2) == 0:
                     pass
@@ -226,18 +243,28 @@ class Pair(Type):
                         acc.car = el
                         return new_pair
                     else:
-                        raise E.InvalidMichelsonException(f"UPDATE {n} requires a right comb of minimum length {n}")
+                        raise E.InvalidMichelsonException(
+                            f"UPDATE {n} requires a right comb of minimum length {n}"
+                        )
 
         if isinstance(prev_acc, Pair):
             prev_acc.cdr = el
         else:
-            raise E.InvalidMichelsonException(f"UPDATE {n} requires a right comb of minimum length {n - 1}")
+            raise E.InvalidMichelsonException(
+                f"UPDATE {n} requires a right comb of minimum length {n - 1}"
+            )
 
         return new_pair
 
 
 class Record(Type):
-    def __init__(self, name: str, attribute_names: Sequence[str], attribute_types: Sequence[Type], annotation: Optional[str] = None):
+    def __init__(
+        self,
+        name: str,
+        attribute_names: Sequence[str],
+        attribute_types: Sequence[Type],
+        annotation: Optional[str] = None,
+    ):
         super().__init__(annotation)
         self.name = name
         self.attribute_names = attribute_names
@@ -246,7 +273,11 @@ class Record(Type):
     def __eq__(self, o):
         if isinstance(o, Pair):
             return self.get_type() == o
-        return type(self) == type(o) and self.attribute_names == o.attribute_names and self.attribute_types == o.attribute_types
+        return (
+            type(self) == type(o)
+            and self.attribute_names == o.attribute_names
+            and self.attribute_types == o.attribute_types
+        )
 
     def __repr__(self):
         return str(self.get_type())
@@ -256,17 +287,17 @@ class Record(Type):
 
     def get_type(self, i=0, acc=None):
         attribute_type = self.attribute_types[i]
-        if acc == None:
+        if acc is None:
             acc = self.make_node(None, None)
 
         if i == 0:
-            return self.make_node(attribute_type, self.get_type(i+1))
+            return self.make_node(attribute_type, self.get_type(i + 1))
 
         elif i == len(self.attribute_types) - 1:
             return attribute_type
 
         else:
-            return self.make_node(attribute_type, self.get_type(i+1))
+            return self.make_node(attribute_type, self.get_type(i + 1))
 
     def get_attribute_type(self, attribute_name: str):
         attribute_index = self.attribute_names.index(attribute_name)
@@ -286,19 +317,21 @@ class List(Type):
     def __repr__(self):
         return f"{self.element_type} list"
 
+
 class Operations(Type):
     def __init__(self, annotation: Optional[str] = None):
         self.element_type = Operation()
         super().__init__(annotation)
 
     def __repr__(self):
-        return f"operation list"
+        return "operation list"
 
     def __eq__(self, o):
         if isinstance(o, List):
             return self.element_type == o.element_type
         return type(self) == type(o) and self.element_type == o.element_type
 
+
 class Set(Type):
     def __init__(self, element_type: Type, annotation: Optional[str] = None):
         super().__init__(annotation)
@@ -310,6 +343,7 @@ class Set(Type):
     def __repr__(self):
         return f"{self.element_type} set"
 
+
 class Spread(Type):
     def __init__(self, element_type: Type, annotation: Optional[str] = None):
         super().__init__(annotation)
@@ -320,26 +354,38 @@ class Spread(Type):
 
 
 class Dict(Type):
-    def __init__(self, key_type: Type, value_type: Type, annotation: Optional[str] = None):
+    def __init__(
+        self, key_type: Type, value_type: Type, annotation: Optional[str] = None
+    ):
         super().__init__(annotation)
         self.key_type = key_type
         self.value_type = value_type
 
     def __eq__(self, o):
-        return type(self) == type(o) and self.key_type == o.key_type and self.value_type == o.value_type
+        return (
+            type(self) == type(o)
+            and self.key_type == o.key_type
+            and self.value_type == o.value_type
+        )
 
     def __repr__(self):
         return f"({self.key_type}, {self.value_type}) map"
 
 
 class BigMap(Type):
-    def __init__(self, key_type: Type, value_type: Type, annotation: Optional[str] = None):
+    def __init__(
+        self, key_type: Type, value_type: Type, annotation: Optional[str] = None
+    ):
         super().__init__(annotation)
         self.key_type = key_type
         self.value_type = value_type
 
     def __eq__(self, o):
-        return type(self) == type(o) and self.key_type == o.key_type and self.value_type == o.value_type
+        return (
+            type(self) == type(o)
+            and self.key_type == o.key_type
+            and self.value_type == o.value_type
+        )
 
     def __repr__(self):
         return f"({self.key_type}, {self.value_type}) big_map"
@@ -353,14 +399,21 @@ class StdlibVariable:
 
 class FunctionPrototype(Type):
     """User defined functions"""
-    def __init__(self, arg_type: Type, return_type: Type, annotation: Optional[str] = None):
+
+    def __init__(
+        self, arg_type: Type, return_type: Type, annotation: Optional[str] = None
+    ):
         super().__init__(annotation)
         self.arg_type = arg_type
         self.return_type = return_type
         self.applied_arg_types = []
 
     def __eq__(self, o):
-        return type(self) == type(o) and self.arg_type == o.arg_type and self.return_type == o.return_type
+        return (
+            type(self) == type(o)
+            and self.arg_type == o.arg_type
+            and self.return_type == o.return_type
+        )
 
     def __repr__(self):
         return f"({self.arg_type}) -> {self.return_type}"
@@ -369,6 +422,7 @@ class FunctionPrototype(Type):
 @dataclass
 class MultiArgFunctionPrototype(Type):
     """Standard library functions"""
+
     arg_types: Sequence[Type]
     return_type: Type
 
@@ -390,7 +444,9 @@ class StdLibClassSpec:
         self.constructor = constructor_spec
         return self
 
-    def create_method(self, name: str, method_spec: StdlibFunctionSpec, is_static=False):
+    def create_method(
+        self, name: str, method_spec: StdlibFunctionSpec, is_static=False
+    ):
         self.methods[name] = method_spec
         if is_static:
             self.static_methods.append(name)
@@ -405,6 +461,7 @@ class StdlibMethodInstance(Type):
     """
     eg. To retrieve `my_dict.add`, retreive `my_dict` and apply its `add` method
     """
+
     def __init__(
         self,
         var_name: str,
@@ -418,13 +475,18 @@ class StdlibMethodInstance(Type):
         self.compile_callback = compile_callback
 
     def __eq__(self, o):
-        return self.var_name == o.var_name and self.signature == o.signature and self.compile_callback == o.compile_callback
+        return (
+            self.var_name == o.var_name
+            and self.signature == o.signature
+            and self.compile_callback == o.compile_callback
+        )
 
 
 class StdlibStaticMethodInstance(Type):
     """
     eg. To retrieve `Timestamp.now`
     """
+
     def __init__(
         self,
         signature: StdlibFunctionSpec,
@@ -436,8 +498,10 @@ class StdlibStaticMethodInstance(Type):
         self.compile_callback = compile_callback
 
     def __eq__(self, o):
-        return self.signature == o.signature and self.compile_callback == o.compile_callback
-
+        return (
+            self.signature == o.signature
+            and self.compile_callback == o.compile_callback
+        )
 
 
 class Contract(Type):
@@ -452,7 +516,6 @@ class Contract(Type):
         return f"{self.param_type} contract"
 
 
-
 base_types = [
     "Unit",
     "Nat",
@@ -474,54 +537,63 @@ polymorphic_types = [
     "Contract",
 ]
 
-record_types = [
-    "Records"
-]
+record_types = ["Records"]
+
 
 class TypeParser:
     def __init__(self):
         pass
 
-    def parse_name(self, name: ast.Name, e, annotation: Optional[str] = None, lineno = 0) -> Type:
-        if name.id == 'Int':
+    def parse_name(
+        self, name: ast.Name, e, annotation: Optional[str] = None, lineno=0
+    ) -> Type:
+        if name.id == "Int":
             return Int(annotation)
-        if name.id == 'Nat':
+        if name.id == "Nat":
             return Nat(annotation)
-        if name.id == 'String':
+        if name.id == "String":
             return String(annotation)
-        if name.id == 'Address':
+        if name.id == "Address":
             return Address(annotation)
-        if name.id == 'bool':
+        if name.id == "bool":
             return Bool(annotation)
-        if name.id == 'unit' or name.id == 'Unit':
+        if name.id == "unit" or name.id == "Unit":
             return Unit(annotation)
-        if name.id == 'Mutez':
+        if name.id == "Mutez":
             return Mutez(annotation)
-        if name.id == 'Bytes':
+        if name.id == "Bytes":
             return Bytes(annotation)
-        if name.id == 'datetime':
+        if name.id == "datetime":
             return Datetime(annotation)
-        if name.id == 'Timestamp':
+        if name.id == "Timestamp":
             return Datetime(annotation)
-        if name.id == 'Operations':
+        if name.id == "Operations":
             return Operations()
         if name.id in e.types.keys():
             return e.types[name.id]
 
         allowed_annotations = base_types + record_types
-        raise E.TypeAnnotationDoesNotExistException(name.id, allowed_annotations, lineno)
+        raise E.TypeAnnotationDoesNotExistException(
+            name.id, allowed_annotations, lineno
+        )
 
-    def parse_dict(self, dictionary: ast.Subscript, e, annotation: Optional[str] = None):
+    def parse_dict(
+        self, dictionary: ast.Subscript, e, annotation: Optional[str] = None
+    ):
         key_type = self.parse(dictionary.slice.elts[0], e)
         value_type = self.parse(dictionary.slice.elts[1], e)
         return Dict(key_type, value_type, annotation)
 
-    def parse_big_map(self, big_map: ast.Subscript, e, annotation: Optional[str] = None):
+    def parse_big_map(
+        self, big_map: ast.Subscript, e, annotation: Optional[str] = None
+    ):
         key_type = self.parse(big_map.slice.elts[0], e)
         value_type = self.parse(big_map.slice.elts[1], e)
         return BigMap(key_type, value_type, annotation)
 
-    def parse_callable(self, dictionary: ast.Subscript, e, annotation: Optional[str] = None):
+    def parse_callable(
+        self, dictionary: ast.Subscript, e, annotation: Optional[str] = None
+    ):
         key_type = self.parse(dictionary.slice.elts[0].elts[0], e)
         value_type = self.parse(dictionary.slice.elts[1], e)
         return FunctionPrototype(key_type, value_type, annotation)
@@ -538,7 +610,9 @@ class TypeParser:
         param_type = self.parse(set_.slice, e)
         return Set(param_type, annotation)
 
-    def parse_subscript(self, subscript: ast.Subscript, e, annotation: Optional[str] = None, lineno = 0):
+    def parse_subscript(
+        self, subscript: ast.Subscript, e, annotation: Optional[str] = None, lineno=0
+    ):
         if subscript.value.id == "Dict":
             return self.parse_dict(subscript, e, annotation)
         if subscript.value.id == "BigMap":
@@ -554,10 +628,14 @@ class TypeParser:
         if subscript.value.id == "Set":
             return self.parse_set(subscript, e, annotation)
         else:
-            allowed_annotations = f"only polymorphic types ({polymorphic_types}) are subscriptable"
-            raise E.TypeAnnotationDoesNotExistException(subscript.value.id, allowed_annotations, lineno)
+            allowed_annotations = (
+                f"only polymorphic types ({polymorphic_types}) are subscriptable"
+            )
+            raise E.TypeAnnotationDoesNotExistException(
+                subscript.value.id, allowed_annotations, lineno
+            )
 
-    def parse(self, type_ast, e, annotation: Optional[str] = None, lineno = 0) -> Type:
+    def parse(self, type_ast, e, annotation: Optional[str] = None, lineno=0) -> Type:
         if type(type_ast) == ast.Name:
             return self.parse_name(type_ast, e, annotation, lineno)
         if type(type_ast) == ast.Constant:
@@ -568,7 +646,7 @@ class TypeParser:
             else:
                 raise E.CompilerException(f"Unsupported type: {type_ast}", lineno)
         if type(type_ast) == ast.Subscript:
-           return self.parse_subscript(type_ast, e, annotation, lineno)
+            return self.parse_subscript(type_ast, e, annotation, lineno)
         if type(type_ast) == ast.Tuple:
             attribute_names = []
             attribute_types = []
@@ -576,12 +654,11 @@ class TypeParser:
                 attribute_names.append(str(i))
                 attribute_types.append(self.parse(elt, e, annotation, lineno))
             return Record("_", attribute_names, attribute_types)
-        if type_ast == None:
+        if type_ast is None:
             return Unit()
         raise E.TypeAnnotationDoesNotExistException(
             ast.dump(type_ast),
-            f"expected a base type ({base_types}) or an polymorphic type ({polymorphic_types})",
-            type_ast.lineno
-            )
-        raise NotImplementedError
-
+            f"expected a base type ({base_types})"
+            + f" or an polymorphic type ({polymorphic_types})",
+            type_ast.lineno,
+        )
